==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/api/mixer/v1/HeaderOperationFluentImpl.java <==
package me.snowdrop.istio.api.mixer.v1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class HeaderOperationFluentImpl<A extends HeaderOperationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements HeaderOperationFluent<A>{

    private String name;
    private Operation operation;
    private String value;

    public HeaderOperationFluentImpl(){
    }
    public HeaderOperationFluentImpl(HeaderOperation instance){
            this.withName(instance.getName()); 
            this.withOperation(instance.getOperation()); 
            this.withValue(instance.getValue()); 
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public Operation getOperation(){
            return this.operation;
    }

    public A withOperation(Operation operation){
            this.operation=operation; return (A) this;
    }

    public Boolean hasOperation(){
            return this.operation != null;
    }

    public String getValue(){
            return this.value;
    }

    public A withValue(String value){
            this.value=value; return (A) this;
    }

    public Boolean hasValue(){
            return this.value != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            HeaderOperationFluentImpl that = (HeaderOperationFluentImpl) o;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (operation != null ? !operation.equals(that.operation) :that.operation != null) return false;
            if (value != null ? !value.equals(that.value) :that.value != null) return false;
            return true;
    }




}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/api/mixer/v1/HeaderOperationFluentImpl.java <==
package me.snowdrop.istio.api.mixer.v1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class HeaderOperationFluentImpl<A extends HeaderOperationFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements HeaderOperationFluent<A>{

    private String name;
    private Operation operation;
    private String value;

    public HeaderOperationFluentImpl(){
    }
    public HeaderOperationFluentImpl(HeaderOperation instance){
            this.withName(instance.getName()); 
            this.withOperation(instance.getOperation()); 
            this.withValue(instance.getValue()); 
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public A withNewName(String arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1){
            return (A)withName(new String(arg1));
    }

    public Operation getOperation(){
            return this.operation;
    }

    public A withOperation(Operation operation){
            this.operation=operation; return (A) this;
    }

    public Boolean hasOperation(){
            return this.operation != null;
    }

    public String getValue(){
            return this.value;
    }

    public A withValue(String value){
            this.value=value; return (A) this;
    }

    public Boolean hasValue(){
            return this.value != null;
    }

    public A withNewValue(String arg1){
            return (A)withValue(new String(arg1));
    }

    public A withNewValue(StringBuilder arg1){
            return (A)withValue(new String(arg1));
    }

    public A withNewValue(StringBuffer arg1){
            return (A)withValue(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            HeaderOperationFluentImpl that = (HeaderOperationFluentImpl) o;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (operation != null ? !operation.equals(that.operation) :that.operation != null) return false;
            if (value != null ? !value.equals(that.value) :that.value != null) return false;
            return true;
    }




}
